---
name: "\U0001F41B Bug Report"
about: Something doesn't work
title: ''
labels: ''
assignees: ''

---

<!-- Check those before opening an issue -->

- [ ] I have searched through existing issues
- [ ] I have read through [docs](https://vuejs.github.io/vetur)
- [ ] I have read [FAQ](https://vuejs.github.io/vetur/guide/FAQ.html)
- [ ] I have tried restarting VS Code or running `Vetur: Restart VLS`

## Info

- Platform: <!-- Win/macOS/Linux -->
- Vetur version:
- VS Code version:
- TypeScript version:
- Vetur output:
<details><summary>Output</summary>
<p>

```
<!-- Run VSCode command `Vetur: Show output panel` -->
```

</p>
</details>
- Vetur doctor output
<details><summary>Doctor output</summary>
<p>

```
<!-- Run VSCode command `Vetur: Show doctor info` -->
```

</p>
</details>

## Problem

<!-- Include error message from Panel -> Output -> Vue Language Server -->
<!-- With screenshot / gif if possible -->

## Reproducible Case

<!--
  Please provide clear steps for reproducing the problem. Otherwise we might close your issue.

  - Generate a project from https://github.com/octref/veturpack/generate
  - Make a minimal code change to demonstrate your problem
  - Push your commit
  - Include link to your changes in the issue
-->
